getPlatformVersion method
Returns the Windows platform version from the native plugin.
Implementation
@override
/// Returns the Windows platform version from the native plugin.
Future<String?> getPlatformVersion() async {
final version = await methodChannel.invokeMethod<String>(
'getPlatformVersion',
);
return version;
}