methodChannel property
Method channel used to interact with the native Windows plugin.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('attriax_flutter_windows');
Method channel used to interact with the native Windows plugin.
@visibleForTesting
final methodChannel = const MethodChannel('attriax_flutter_windows');