AttriaxFlutterWindowsPlatform class abstract

Platform interface for the Attriax Windows Flutter plugin.

Inheritance
  • Object
  • PlatformInterface
  • AttriaxFlutterWindowsPlatform
Implementers

Constructors

AttriaxFlutterWindowsPlatform()
Creates the base platform interface implementation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the Windows platform version reported by the native plugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AttriaxFlutterWindowsPlatform
Returns the active platform implementation.
getter/setter pair